@@ -6,12 +6,13 @@ import PIL.Image
 import numpy as np
 
 
-def load_image(image_filepath, image_size, scale, subtract_value):
+def load_image(image_filepath, image_size, scale, subtract_value, bgr):
     image = PIL.Image.open(image_filepath)
     image = image.resize((image_size, image_size), PIL.Image.ANTIALIAS)
     image = np.array(image, dtype=np.float32) / 255
     image *= scale
     image -= subtract_value
+    image = image[:, :, (2, 1, 0)] if bgr else image
 
     image = image[np.newaxis, :]
 
@@ -28,12 +29,13 @@ def main():
     parser.add_argument('--size', type=int, default=224, help="input size")
     parser.add_argument('--scale', type=float, default=1)
     parser.add_argument('--subtract', type=float, default=0)
+    parser.add_argument('--bgr', action='store_true')
 
     args = parser.parse_args()
     if not args.image_filepath.exists():
         parser.error(f"{args.image_filepath} doesn't exist.")
 
-    load_image(args.image_filepath, args.size, args.scale, args.subtract)
+    load_image(args.image_filepath, args.size, args.scale, args.subtract, args.bgr)
 
 
 if __name__ == '__main__':
