@@ -1,10 +1,11 @@
 import tempfile
 import pathlib
-import onnx
-import onnxruntime
+import numpy as np
 
 
 def _add_output_node(input_model_filepath, output_model_filepath, output_node_names):
+    import onnx
+
     model = onnx.ModelProto()
     model.ParseFromString(input_model_filepath.read_bytes())
     existing_output_names = set([o.name for o in model.graph.output])
@@ -15,6 +16,8 @@ def _add_output_node(input_model_filepath, output_model_filepath, output_node_na
 
 
 def run_model(model_filepath, input_array, output_names):
+    import onnxruntime
+
     if output_names:
         with tempfile.TemporaryDirectory() as tempdir:
             temp_model_filepath = pathlib.Path(tempdir) / 'model.onnx'
@@ -25,6 +28,10 @@ def run_model(model_filepath, input_array, output_names):
         sess = onnxruntime.InferenceSession(str(model_filepath))
         output_names = [o.name for o in sess.get_outputs()]
 
+    # TODO: Support more types?
+    if sess.get_inputs()[0].type == 'tensor(float16)':
+        input_array = input_array.astype(np.float16)
+
     outputs = sess.run(output_names, {sess.get_inputs()[0].name: input_array})
 
     return {n: outputs[i] for i, n in enumerate(output_names)}
